This function downloads a requested color palette from color-hex.com. This website provides a large number of user-submitted color palettes.
Arguments
- palette
The numeric code for a palette at color-hex.com. For example,
1014416for the Josiah color palette (number 1014416).- reverse
Boolean indicating whether the palette should be reversed.
- ...
Additional arguments to pass to
colorRampPalette().
Details
This function is usually not called directly, but from within
scale_color_colorhex().