Skip to contents

The plot() method for the datawizard::means_by_group() function.

Usage

# S3 method for class 'see_dw_groupmeans'
plot(x, title = "", ci = TRUE, caption = TRUE, ...)

Arguments

x

An object returned datawizard::means_by_group().

title

String, can be used to specify a plot title.

ci

Logical, indicating if the confidence intervals should be included in the graph.

caption

Logical, indicating if a caption summarizing the anova results for the analysis should be included.

...

Currently not used.

Details

Produces a faceted plot when there is more than one means-table.

Examples

# \dontrun{
group_means_object <-  datawizard::means_by_group(iris$Sepal.Width, iris$Species)
plot(group_means_object, title = "group means", ci = FALSE, caption = FALSE)
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter
#> Warning: "title" is not a graphical parameter
#> Warning: "ci" is not a graphical parameter
#> Warning: "caption" is not a graphical parameter


group_means_object <- datawizard::means_by_group(
  iris,
  c("Sepal.Width", "Petal.Width"),
  "Species"
)
plot(group_means_object, title = "group means")
#> Error in xy.coords(x, y, xlabel, ylabel, log): 'x' is a list, but does not have components 'x' and 'y'
# }