- x
An object.
- data
The original data used to create this object. Can be a
statistical model.
- show_intercept
Logical, if TRUE, the intercept-parameter is included
in the plot. By default, it is hidden because in many cases the
intercept-parameter has a posterior distribution on a very different
location, so density curves of posterior distributions for other parameters
are hardly visible.
- priors
Logical. If TRUE, prior distributions are simulated
(using bayestestR::simulate_prior()) and added
to the plot.
- priors_alpha
Numeric value specifying alpha for the prior
distributions.
- n_columns
For models with multiple components (like fixed and random,
count and zero-inflated), defines the number of columns for the
panel-layout. If NULL, a single, integrated plot is shown.
- ...
Arguments passed to or from other methods.